@@ -4,100 +4,82 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="83"/>
-        <location filename="../src/board.cpp" line="872"/>
         <source>Details</source>
         <translation>Részletek</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="112"/>
         <source>Clear</source>
         <translation>Ürít</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="126"/>
         <source>Guess</source>
         <translation>Megfejt</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="156"/>
         <source>Found</source>
         <translation>Megfejtett</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Normal</source>
         <translation>Átlagos</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Large</source>
         <translation>Nagy</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="314"/>
         <source>Missed</source>
         <translation>Kihagyott</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="448"/>
         <source>Error</source>
         <translation>Hibás</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Success</source>
         <translation>Sikeres</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Game Over</source>
         <translation>Vége a játéknak</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="793"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 / %n pont</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="795"/>
         <source>3 of %n point(s)</source>
         <translation>
             <numerusform>3 / %n pont</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="797"/>
         <source>2 of %n point(s)</source>
         <translation>
             <numerusform>2 / %n pont</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="799"/>
         <source>1 of %n point(s)</source>
         <translation>
             <numerusform>1 / %n pont</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="801"/>
         <source>0 of %n point(s)</source>
         <translation>
             <numerusform>0 / %n pont</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="805"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n pont</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="881"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>A legmagasabb elérhető pontszám a következő harminc szóból került kiszámításra:</translation>
     </message>
@@ -105,96 +87,78 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="93"/>
         <source>m:ss</source>
         <translation>m:ss</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="154"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n megfejtés</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="280"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="344"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n hiba</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Classic</source>
         <translation>Klasszikus</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Refill</source>
         <translation>Újratöltő</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Stamina</source>
         <translation>Kitartó</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Strikeout</source>
         <translation>Büntető</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="524"/>
         <source>Allotment</source>
         <translation>Tarsoly</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="525"/>
         <source>Discipline</source>
         <translation>Fegyelem</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Visszaszámlálás 30 másodpercről és megfejtés esetén időt nyersz.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Visszaszámlálás 3 percről.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Visszaszámlálás 30 másodpercről és ez minden megfejtésnél újraindul.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Visszaszámlálás 45 másodpercről és megfejtés esetén szünidőt nyersz.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>3 hibás megfejtés után vége a játéknak.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="538"/>
         <source>Game ends after 30 guesses.</source>
         <translation>30 megfejtés után vége a játéknak.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="539"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Visszaszámlálás 30 másodpercről és helyes vagy hibás megfejtés esetén időt nyersz vagy vesztesz.</translation>
     </message>
@@ -202,12 +166,10 @@
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="273"/>
         <source>Unable to read dice from file.</source>
         <translation>Nem sikerült beolvasni a kocka fájlt.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="351"/>
         <source>Unable to read word list from file.</source>
         <translation>Nem sikerült beolvasni a szó-lista fájlt.</translation>
     </message>
@@ -215,53 +177,42 @@
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Szavak nyelve</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Egyéni</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
         <translation>Kiválaszt...</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Megjegyzés:&lt;/b&gt; A változások új játék esetén lépnek érvénybe.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Nyelv:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Kocka:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
         <translation>Szavak listája:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Szótár:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
         <translation>Kocka fájl kiválasztása</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="214"/>
         <source>Choose Word List File</source>
         <translation>Szó-lista fájl kiválasztása</translation>
     </message>
@@ -269,22 +220,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Program nyelve:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Rendszer nyelve&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Note</source>
         <translation>Megjegyzés</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>A nyelvi változások érvénybelépéséhez újra kell indítani a programot.</translation>
     </message>
@@ -292,42 +239,34 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Új játék</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation>Szavak száma:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation>Legrövidebb szó:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation>Kevés</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation>Közepes</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation>Sok</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation>Véletlenszerű</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n betű</numerusform>
@@ -337,42 +276,34 @@
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Eredmények</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
         <source>&lt;b&gt;Name&lt;/b&gt;</source>
         <translation>&lt;b&gt;Név&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
         <source>&lt;b&gt;Score&lt;/b&gt;</source>
         <translation>&lt;b&gt;Eredmény&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
         <source>&lt;b&gt;Date&lt;/b&gt;</source>
         <translation>&lt;b&gt;Dátum&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
         <source>&lt;b&gt;Timer&lt;/b&gt;</source>
         <translation>&lt;b&gt;Típus&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Question</source>
         <translation>Kérdés</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Clear high scores?</source>
         <translation>Eredmények törlése?</translation>
     </message>
@@ -380,312 +311,246 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="32"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="301"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Szünet&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Kattints a folytatáshoz.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Játék betöltése...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="312"/>
         <source>Click to start a new game.</source>
         <translation>Kattints az új játékhoz.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Új tábla készítése...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="323"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Kérlek várj&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Szó-lista optimalizációja...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="328"/>
         <source>&amp;Game</source>
         <translation>&amp;Játék</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>New &amp;Game...</source>
         <translation>Új &amp;játék...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="330"/>
         <source>&amp;New Roll</source>
         <translation>Új&amp;rakever</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="331"/>
         <source>&amp;Choose...</source>
         <translation>K&amp;iválaszt...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="332"/>
         <source>&amp;Share...</source>
         <translation>&amp;Megoszt...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;End</source>
         <translation>&amp;Befejez</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Pause</source>
         <translation>&amp;Szünet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="339"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="344"/>
         <source>&amp;Details</source>
         <translation>Részle&amp;tek</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="346"/>
         <source>&amp;High Scores</source>
         <translation>&amp;Eredmények</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>&amp;Quit</source>
         <translation>&amp;Kilépés</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="353"/>
         <source>&amp;Settings</source>
         <translation>B&amp;eállítások</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Show &amp;Maximum Score</source>
         <translation>Elérhető &amp;pontok</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="356"/>
         <source>&amp;Never</source>
         <translation>&amp;Ne mutasd</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="357"/>
         <source>&amp;End Of Game</source>
         <translation>Játék &amp;végén</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="358"/>
         <source>&amp;Always</source>
         <translation>&amp;Mindig</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="366"/>
         <source>Show Missed &amp;Words</source>
         <translation>El&amp;hibázott szavak</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="369"/>
         <source>Show Word &amp;Counts</source>
         <translation>Szavak szá&amp;ma</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="373"/>
         <source>&amp;Board Language...</source>
         <translation>Szavak &amp;nyelve...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Application &amp;Language...</source>
         <translation>Program nye&amp;lve...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Help</source>
         <translation>&amp;Segítség</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="380"/>
         <source>&amp;Controls</source>
         <translation>&amp;Irányítás</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="382"/>
         <source>&amp;About</source>
         <translation>&amp;Névjegy</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="384"/>
         <source>About &amp;Hspell</source>
         <translation>&amp;Hspell névjegye</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>About &amp;Qt</source>
         <translation>&amp;Qt névjegye</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>About &amp;SCOWL</source>
         <translation>&amp;SCOWL névjegye</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="470"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="468"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="466"/>
         <source>About</source>
         <translation>Névjegy</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="469"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>A &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; egyjátékos változata</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="471"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
         <translation>Angol szó-lista fájl Kevin Atkinson &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; listája alapján</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="473"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Héber szó-lista fájl Nadav Har&apos;El és Dan Kenigsberg &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; listája alapján</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="480"/>
         <source>About Hspell</source>
         <translation>Hspell névjegye</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>About SCOWL</source>
         <translation>SCOWL névjegye</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="516"/>
         <source>Import Game</source>
         <translation>Játék betöltése</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="518"/>
-        <location filename="../src/window.cpp" line="578"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation>Tanglet játékok (*.tanglet)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="533"/>
-        <location filename="../src/window.cpp" line="548"/>
-        <location filename="../src/window.cpp" line="557"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Unable to start requested game.</source>
         <translation>Nem sikerült elindítani a kívánt játékot.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="566"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="576"/>
         <source>Export Game</source>
         <translation>Játék mentése</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>Question</source>
         <translation>Kérdés</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>End the current game?</source>
         <translation>Játék befejezése?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="662"/>
         <source>Details</source>
         <translation>Részletek</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Board Size:</source>
         <translation>Tábla mérete:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Normal</source>
         <translation>Átlagos</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Large</source>
         <translation>Nagy</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="669"/>
         <source>Word Density:</source>
         <translation>Szavak száma:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>Word Length:</source>
         <translation>Szavak hossza:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>%1 or more letters</source>
         <translation>%1 vagy több betű</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="671"/>
         <source>Game Type:</source>
         <translation>Játék típusa:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="672"/>
         <source>Description:</source>
         <translation>Leírás:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>Controls</source>
         <translation>Irányítás</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Egérrel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Kattints a szó betűire.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Kattints az utolsó kijejölt betűre.&lt;br&gt;&lt;b&gt;Betű törlése:&lt;/b&gt; Kattints a korábban kijelölt betűre.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Kattints kétszer az első kijelölt betűre.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Billentyűzettel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Írd be a szó betűit.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Üsd le az Enter billentyűt.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Üsd le a Ctrl+Backspace billentyűkombinációt.&lt;/p&gt;</translation>
     </message>
@@ -693,27 +558,22 @@
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Letters:</source>
         <translation>Betűk:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Found:</source>
         <translation>Megfejtett:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="117"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="124"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation>%1&lt;br&gt;%2/%3</translation>
     </message>
@@ -721,11 +581,21 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="93"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n pont</numerusform>
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
