@@ -4,58 +4,46 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="83"/>
-        <location filename="../src/board.cpp" line="872"/>
         <source>Details</source>
         <translation>Detalii</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="112"/>
         <source>Clear</source>
         <translation>Şterge</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="126"/>
         <source>Guess</source>
         <translation>Presupuneri</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="156"/>
         <source>Found</source>
         <translation>Găsit</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Large</source>
         <translation>Mare</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="314"/>
         <source>Missed</source>
         <translation>Ratat</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="448"/>
         <source>Error</source>
         <translation>Eroare</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Success</source>
         <translation>Succes</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Game Over</source>
         <translation>Joc terminat</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="793"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 punct din %n</numerusform>
@@ -64,7 +52,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="795"/>
         <source>3 of %n point(s)</source>
         <translation>
             <numerusform>3 din %n punct</numerusform>
@@ -73,7 +60,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="797"/>
         <source>2 of %n point(s)</source>
         <translation>
             <numerusform>2 din %n punct</numerusform>
@@ -82,7 +68,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="799"/>
         <source>1 of %n point(s)</source>
         <translation>
             <numerusform>1 din %n punct</numerusform>
@@ -91,7 +76,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="801"/>
         <source>0 of %n point(s)</source>
         <translation>
             <numerusform>0 din %n punct</numerusform>
@@ -100,7 +84,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="805"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n punct</numerusform>
@@ -109,7 +92,6 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="881"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>Punctajul maxim a fost calculat din următoarele treizeci de cuvinte:</translation>
     </message>
@@ -117,12 +99,10 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="93"/>
         <source>m:ss</source>
         <translation>m:ss</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="154"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n presupunere</numerusform>
@@ -131,12 +111,10 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="280"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="344"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n ratare</numerusform>
@@ -145,72 +123,58 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Classic</source>
         <translation>Clasic</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Refill</source>
         <translation>Reumplere</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Stamina</source>
         <translation>Vigoare</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Strikeout</source>
         <translation>Ratări</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="524"/>
         <source>Allotment</source>
         <translation>Repartizare</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="525"/>
         <source>Discipline</source>
         <translation>Disciplină</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Numărătoare inversă de la 30 secunde şi reumplere la presupunerile corecte.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Numărătoare inversă de la 3 minute.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Numărătoare inversă de la 30 secunde şi reumplere la presupunerile corecte.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Numărătoare inversă de la 45 secunde şi pauză la presupunerile corecte.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>Jocul se termină după 3 presupuneri greşite.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="538"/>
         <source>Game ends after 30 guesses.</source>
         <translation>Jocul se termină după 30 presupuneri.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="539"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Numărătoare inversă de la 30 secunde şi creşte sau scade la presupunerile corecte.</translation>
     </message>
@@ -218,12 +182,10 @@
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="273"/>
         <source>Unable to read dice from file.</source>
         <translation>Nu se pot citi cuburile din fişier.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="351"/>
         <source>Unable to read word list from file.</source>
         <translation>Nu se poate citi lista cuvintelor din fişier.</translation>
     </message>
@@ -231,53 +193,42 @@
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Limbaj planşetă</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Personalizat</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
         <translation>Alegeţi...</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Notă:&lt;/b&gt; Aceste setări vor avea efect la începerea unui nou joc.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Limbă:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Cuburi:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
         <translation>Listă cuvinte:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Dicţionar:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
         <translation>Alegeţi fişierul cuburi</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="214"/>
         <source>Choose Word List File</source>
         <translation>Alegeţi fişierul listă de cuvinte</translation>
     </message>
@@ -285,22 +236,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Selectaţi limba aplicaţiei:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Limbaj Sistem&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Note</source>
         <translation>Notă</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
     </message>
@@ -308,42 +255,34 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Joc nou</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation>Cantitate cuvinte:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation>Mărime minimă cuvinte:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation>Mică</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation>Medie</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation>Mare</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation>Aleatoare</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n literă</numerusform>
@@ -355,42 +294,34 @@
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Scoruri record</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
         <source>&lt;b&gt;Name&lt;/b&gt;</source>
         <translation>&lt;b&gt;Nume&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
         <source>&lt;b&gt;Score&lt;/b&gt;</source>
         <translation>&lt;b&gt;Scor&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
         <source>&lt;b&gt;Date&lt;/b&gt;</source>
         <translation>&lt;b&gt;Dată&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
         <source>&lt;b&gt;Timer&lt;/b&gt;</source>
         <translation>&lt;b&gt;Temporizator&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Question</source>
         <translation>Întrebare</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Clear high scores?</source>
         <translation>Şterge scoruri record?</translation>
     </message>
@@ -398,312 +329,246 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="32"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="301"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;În pauză&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Clic petru a relua jocul.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Încărcare joc...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="312"/>
         <source>Click to start a new game.</source>
         <translation>Clic pentru a începe joc nou.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generare planşetă nouă...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="323"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Vă rugăm aşteptaţi&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizare listă cuvinte...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="328"/>
         <source>&amp;Game</source>
         <translation>&amp;Joc</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>New &amp;Game...</source>
         <translation>Joc &amp;nou...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="330"/>
         <source>&amp;New Roll</source>
         <translation>Pornire &amp;nouă</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="331"/>
         <source>&amp;Choose...</source>
         <translation>Alegeţi...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="332"/>
         <source>&amp;Share...</source>
         <translation>Distribuie...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;End</source>
         <translation>Sfîrşit</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pauză</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="339"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="344"/>
         <source>&amp;Details</source>
         <translation>&amp;Detalii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="346"/>
         <source>&amp;High Scores</source>
         <translation>&amp;Scoruri record</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>&amp;Quit</source>
         <translation>&amp;Ieşire</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="353"/>
         <source>&amp;Settings</source>
         <translation>&amp;Setări</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Show &amp;Maximum Score</source>
         <translation>Arată scor &amp;maxim</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="356"/>
         <source>&amp;Never</source>
         <translation>&amp;Niciodată</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="357"/>
         <source>&amp;End Of Game</source>
         <translation>Sfîrşitul jocului</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="358"/>
         <source>&amp;Always</source>
         <translation>Mereu</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="366"/>
         <source>Show Missed &amp;Words</source>
         <translation>Arată cuvinte &amp;ratate</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="369"/>
         <source>Show Word &amp;Counts</source>
         <translation>Arată numărul de cuvinte</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="373"/>
         <source>&amp;Board Language...</source>
         <translation>Limbaj planşetă...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Application &amp;Language...</source>
         <translation>&amp;Limbă aplicaţie...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Help</source>
         <translation>&amp;Ajutor</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="380"/>
         <source>&amp;Controls</source>
         <translation>&amp;Controale</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="382"/>
         <source>&amp;About</source>
         <translation>&amp;Despre</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="384"/>
         <source>About &amp;Hspell</source>
         <translation>Despre &amp;Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>About &amp;Qt</source>
         <translation>Despre &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>About &amp;SCOWL</source>
         <translation>Despre &amp;SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="470"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Toate drepturile rezervate &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="468"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="466"/>
         <source>About</source>
         <translation>Despre</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="469"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>Varianta un singur jucător a  &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="471"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Lansat sub licenţă &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
         <translation>Lista cuvintelor englezeşti este bazată pe &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; de Kevin Atkinson</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="473"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Lista cuvintelor ebraice este bazată pe &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El şi Dan Kenigsberg</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="480"/>
         <source>About Hspell</source>
         <translation>Despre Hspell</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>About SCOWL</source>
         <translation>Despre SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="516"/>
         <source>Import Game</source>
         <translation>Importă joc</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="518"/>
-        <location filename="../src/window.cpp" line="578"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation>Jocuri Tanglet (*.tanglet)</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="533"/>
-        <location filename="../src/window.cpp" line="548"/>
-        <location filename="../src/window.cpp" line="557"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Unable to start requested game.</source>
         <translation>Nu se poate începe jocul solicitat.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="566"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Error</source>
         <translation>Eroare</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="576"/>
         <source>Export Game</source>
         <translation>Exportă joc</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>Question</source>
         <translation>Întrebare</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>End the current game?</source>
         <translation>Încheiaţi jocul curent?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="662"/>
         <source>Details</source>
         <translation>Detalii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Board Size:</source>
         <translation>Mărime planşetă:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Large</source>
         <translation>Mare</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="669"/>
         <source>Word Density:</source>
         <translation>Densitate cuvinte:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>Word Length:</source>
         <translation>Mărime cuvinte:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>%1 or more letters</source>
         <translation>%1 sau mai multe litere</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="671"/>
         <source>Game Type:</source>
         <translation>Tip joc:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="672"/>
         <source>Description:</source>
         <translation>Descriere:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>Controls</source>
         <translation>Controale</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu mouse-ul:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; Faceţi click pe literele unui cuvînt.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Faceţi click pe ultima literă selectată.&lt;br&gt;&lt;b&gt;Ştergeţi literele:&lt;/b&gt; Faceţi click pe o literă anterior selectată.&lt;br&gt;&lt;b&gt;Ştergeţi cuvînt:&lt;/b&gt; Faceţi clic de două ori pe prima literă selectată.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu tastatura:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; TTastaţi literele cuvîntului.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Apăsaţi Enter.&lt;br&gt;&lt;b&gt;Ştergeţi cuvîntul:&lt;/b&gt; Apăsaţi Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
@@ -711,27 +576,22 @@
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Letters:</source>
         <translation>Litere:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Found:</source>
         <translation>Găsit:</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="117"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="124"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation>%1&lt;br&gt;%2/%3</translation>
     </message>
@@ -739,7 +599,6 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="93"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n punct</numerusform>
@@ -748,4 +607,15 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation>Joc de găsire a cuvintelor</translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation>Un fişier al jocului de jucat.</translation>
+    </message>
+</context>
 </TS>
